from typing import Dict, Optional
import uuid
import time

class ContextManager:
    def __init__(self, ttl=300):
        self.store: Dict[str, dict] = {}
        self.ttl = ttl  # 上下文存活时间（秒）

    def create_context(self) -> str:
        session_id = str(uuid.uuid4())
        self.store[session_id] = {
            "timestamp": time.time(),
            "last_table": None,
            "aircraft_column": None,
            "base_conditions": {}
        }
        return session_id

    def get_context(self, session_id: str) -> Optional[dict]:
        # if "再" in session_id:
        ctx = self.store.get(session_id)
        if ctx and (time.time() - ctx["timestamp"]) < self.ttl:
            return ctx
        return None

    def update_context(self, session_id: str, **kwargs):
        if session_id in self.store:
            self.store[session_id].update(kwargs)
            self.store[session_id]["timestamp"] = time.time()

context_manager = ContextManager()